<?php

namespace Drupal\orange_dam;

/**
 * The representation of an Orange DAM object.
 */
class OrangeDamContent implements OrangeDamItemInterface {

  /**
   * Some API responses don't include the item type, so set a default.
   */
  const DEFAULT_ITEM_TYPE = 'default';

  /**
   * The systemIdentifier value.
   *
   * @var string
   */
  public $systemIdentifier;

  /**
   * The JSON object data.
   *
   * @var array
   */
  public $data;

  /**
   * The item type.
   *
   * @var string
   */
  public $type;

  /**
   * {@inheritdoc}
   */
  public function __construct(string $id, object $data, string $type = self::DEFAULT_ITEM_TYPE) {
    $this->systemIdentifier = $id;
    $this->data = $data;
    $this->type = $type;
    $this->validateSystemIdentifier($id);
  }

  /**
   * {@inheritdoc}
   */
  public function id() {
    return $this->systemIdentifier;
  }

  /**
   * {@inheritdoc}
   */
  public function data() {
    return $this->data;
  }

  /**
   * {@inheritdoc}
   */
  public function type() {
    return $this->type;
  }

  /**
   * Validates a system identifier.
   *
   * @param string $system_identifier
   *   The Orange DAM system identifier.
   *
   * @return bool
   *   Indication if the system identifier matches the valid pattern.
   *   e.g. EX1STO431061
   *
   * @throws \Exception
   *   If system identifier is invalid.
   */
  public static function validateSystemIdentifier(string $system_identifier) {
    $regex = \Drupal::config('orange_dam.settings')->get('system_identifier_pattern');
    if (empty($regex)) {
      throw new \Exception('Missing Orange DAM system identifier validation pattern configuration.');
    }
    $valid = preg_match($regex, $system_identifier);
    if (!$valid) {
      throw new \Exception(sprintf('Invalid Orange DAM system identifier "%s".', $system_identifier));
    }
    return TRUE;
  }

}
